<?php

namespace Drupal\swisspass\Element;

use Drupal\Core\Form\FormStateInterface;
use Drupal\Core\Render\Element\FormElementBase;

/**
 * Provides a 'swisspass_number' element.
 *
 * @FormElement("swisspass_number")
 */
class SwissPassNumber extends FormElementBase {

  /**
   * {@inheritdoc}
   */
  public function getInfo() {
    $class = get_class($this);
    return [
      '#input' => TRUE,
      '#size' => 13,
      '#maxlength' => 13,
      '#pattern' => '\d{3}-\d{3}-\d{3}-\d',
      '#placeholder' => '000-000-000-0',
      '#process' => [
        [$class, 'processSwissPassNumber'],
        [$class, 'processAjaxForm'],
      ],
      '#element_validate' => [
        [$class, 'validateSwissPassNumber'],
      ],
      '#theme' => 'input__textfield',
      '#theme_wrappers' => ['form_element'],
    ];
  }

  /**
   * {@inheritdoc}
   */
  public static function valueCallback(&$element, $input, FormStateInterface $form_state) {
    if ($input !== false) {
      return $input;
    }
    return isset($element['#default_value']) ? $element['#default_value'] : '';
  }

  /**
   * Processes a SwissPass number element.
   */
  public static function processSwissPassNumber(&$element, FormStateInterface $form_state, &$complete_form) {
    $element['#attached']['library'][] = 'swisspass/swisspass_number';
    return $element;
  }

  /**
   * Validates a SwissPass number element.
   */
  public static function validateSwissPassNumber(&$element, FormStateInterface $form_state, &$complete_form) {
    $value = $element['#value'];
    if (!empty($value) && !preg_match('/^\d{3}-\d{3}-\d{3}-\d$/', $value)) {
      $form_state->setError($element, t('The SwissPass number must be in the format 000-000-000-0.'));
    }
  }

}
