<?php

namespace Drupal\swisspass\Plugin\WebformElement;

use Drupal\webform\Plugin\WebformElement\TextBase;
use Drupal\webform\WebformSubmissionInterface;

/**
 * Provides a 'swisspass_number' element.
 *
 * @WebformElement(
 *   id = "swisspass_number",
 *   label = @Translation("SwissPass Number"),
 *   description = @Translation("Provides a form element for inputting a SwissPass number."),
 *   category = @Translation("Advanced elements"),
 * )
 */
class SwissPassWebformElement extends TextBase {

  /**
   * {@inheritdoc}
   */
  public function getDefaultProperties() {
    return [
        'input_mask' => '999-999-999-9',
      ] + parent::getDefaultProperties();
  }

  /**
   * {@inheritdoc}
   */
  public function prepare(array &$element, WebformSubmissionInterface $webform_submission = NULL) {
    parent::prepare($element, $webform_submission);
    $element['#type'] = 'textfield';
    $element['#pattern'] = '\d{3}-\d{3}-\d{3}-\d';
    $element['#placeholder'] = '000-000-000-0';
    $element['#attributes']['class'][] = 'swisspass-number';
    $element['#element_validate'][] = ['\Drupal\swisspass\Element\SwissPassNumber', 'validateSwissPassNumber'];
    $element['#attached']['library'][] = 'swisspass/swisspass_number';
  }

}
